/*! For license information please see chunk.80348f455b723fbaad26.js.LICENSE */
(self.webpackJsonp=self.webpackJsonp||[]).push([[10],{151:function(t,e){t.exports=function(t,e){var a=0,r={};t.addEventListener("message",function(e){var a=e.data;if("RPC"===a.type)if(a.id){var i=r[a.id];i&&(delete r[a.id],a.error?i[1](Object.assign(Error(a.error.message),a.error)):i[0](a.result))}else{var s=document.createEvent("Event");s.initEvent(a.method,!1,!1),s.data=a.params,t.dispatchEvent(s)}}),e.forEach(function(e){t[e]=function(){for(var i=[],s=arguments.length;s--;)i[s]=arguments[s];return new Promise(function(s,n){var o=++a;r[o]=[s,n],t.postMessage({type:"RPC",id:o,method:e,params:i})})}})}},181:function(t,e,a){"use strict";a(3),a(44),a(41),a(52);var r=a(5),i=a(4);Object(r.a)({_template:i.a`
    <style>
      :host {
        overflow: hidden; /* needed for text-overflow: ellipsis to work on ff */
        @apply --layout-vertical;
        @apply --layout-center-justified;
        @apply --layout-flex;
      }

      :host([two-line]) {
        min-height: var(--paper-item-body-two-line-min-height, 72px);
      }

      :host([three-line]) {
        min-height: var(--paper-item-body-three-line-min-height, 88px);
      }

      :host > ::slotted(*) {
        overflow: hidden;
        text-overflow: ellipsis;
        white-space: nowrap;
      }

      :host > ::slotted([secondary]) {
        @apply --paper-font-body1;

        color: var(--paper-item-body-secondary-color, var(--secondary-text-color));

        @apply --paper-item-body-secondary;
      }
    </style>

    <slot></slot>
`,is:"paper-item-body"})},186:function(t,e,a){"use strict";var r=a(0);const i=t=>(e,a)=>{if(e.constructor._observers){if(!e.constructor.hasOwnProperty("_observers")){const t=e.constructor._observers;e.constructor._observers=new Map,t.forEach((t,a)=>e.constructor._observers.set(a,t))}}else{e.constructor._observers=new Map;const t=e.updated;e.updated=function(e){t.call(this,e),e.forEach((t,e)=>{const a=this.constructor._observers.get(e);void 0!==a&&a.call(this,this[e],t)})}}e.constructor._observers.set(a,t)};function s(t){return{addClass:e=>{t.classList.add(e)},removeClass:e=>{t.classList.remove(e)},hasClass:e=>t.classList.contains(e)}}let n=!1;const o=()=>{},c={get passive(){return n=!0,!1}};document.addEventListener("x",o,c),document.removeEventListener("x",o);a.d(e,"a",function(){return l}),a.d(e,"c",function(){return i}),a.d(e,"b",function(){return s});class l extends r.a{createFoundation(){void 0!==this.mdcFoundation&&this.mdcFoundation.destroy(),this.mdcFoundation=new this.mdcFoundationClass(this.createAdapter()),this.mdcFoundation.init()}firstUpdated(){this.createFoundation()}}},190:function(t,e,a){"use strict";a(3),a(44),a(52),a(142);var r=a(5),i=a(4),s=a(118);Object(r.a)({_template:i.a`
    <style include="paper-item-shared-styles"></style>
    <style>
      :host {
        @apply --layout-horizontal;
        @apply --layout-center;
        @apply --paper-font-subhead;

        @apply --paper-item;
        @apply --paper-icon-item;
      }

      .content-icon {
        @apply --layout-horizontal;
        @apply --layout-center;

        width: var(--paper-item-icon-width, 56px);
        @apply --paper-item-icon;
      }
    </style>

    <div id="contentIcon" class="content-icon">
      <slot name="item-icon"></slot>
    </div>
    <slot></slot>
`,is:"paper-icon-item",behaviors:[s.a]})},212:function(t,e,a){"use strict";a.d(e,"a",function(){return i});var r=a(186);a.d(e,"b",function(){return r.b}),a.d(e,"c",function(){return r.c});class i extends r.a{createRenderRoot(){return this.attachShadow({mode:"open",delegatesFocus:!0})}click(){this.formElement&&(this.formElement.focus(),this.formElement.click())}setAriaLabel(t){this.formElement&&this.formElement.setAttribute("aria-label",t)}firstUpdated(){super.firstUpdated(),this.mdcRoot.addEventListener("change",t=>{this.dispatchEvent(new Event("change",t))})}}},234:function(t,e,a){"use strict";a(3);var r=a(5);Object(r.a)({is:"app-route",properties:{route:{type:Object,notify:!0},pattern:{type:String},data:{type:Object,value:function(){return{}},notify:!0},autoActivate:{type:Boolean,value:!1},_queryParamsUpdating:{type:Boolean,value:!1},queryParams:{type:Object,value:function(){return{}},notify:!0},tail:{type:Object,value:function(){return{path:null,prefix:null,__queryParams:null}},notify:!0},active:{type:Boolean,notify:!0,readOnly:!0},_matched:{type:String,value:""}},observers:["__tryToMatch(route.path, pattern)","__updatePathOnDataChange(data.*)","__tailPathChanged(tail.path)","__routeQueryParamsChanged(route.__queryParams)","__tailQueryParamsChanged(tail.__queryParams)","__queryParamsChanged(queryParams.*)"],created:function(){this.linkPaths("route.__queryParams","tail.__queryParams"),this.linkPaths("tail.__queryParams","route.__queryParams")},__routeQueryParamsChanged:function(t){if(t&&this.tail){if(this.tail.__queryParams!==t&&this.set("tail.__queryParams",t),!this.active||this._queryParamsUpdating)return;var e={},a=!1;for(var r in t)e[r]=t[r],!a&&this.queryParams&&t[r]===this.queryParams[r]||(a=!0);for(var r in this.queryParams)if(a||!(r in t)){a=!0;break}if(!a)return;this._queryParamsUpdating=!0,this.set("queryParams",e),this._queryParamsUpdating=!1}},__tailQueryParamsChanged:function(t){t&&this.route&&this.route.__queryParams!=t&&this.set("route.__queryParams",t)},__queryParamsChanged:function(t){this.active&&!this._queryParamsUpdating&&this.set("route.__"+t.path,t.value)},__resetProperties:function(){this._setActive(!1),this._matched=null},__tryToMatch:function(){if(this.route){var t=this.route.path,e=this.pattern;if(this.autoActivate&&""===t&&(t="/"),e)if(t){for(var a=t.split("/"),r=e.split("/"),i=[],s={},n=0;n<r.length;n++){var o=r[n];if(!o&&""!==o)break;var c=a.shift();if(!c&&""!==c)return void this.__resetProperties();if(i.push(c),":"==o.charAt(0))s[o.slice(1)]=c;else if(o!==c)return void this.__resetProperties()}this._matched=i.join("/");var l={};this.active||(l.active=!0);var u=this.route.prefix+this._matched,h=a.join("/");for(var d in a.length>0&&(h="/"+h),this.tail&&this.tail.prefix===u&&this.tail.path===h||(l.tail={prefix:u,path:h,__queryParams:this.route.__queryParams}),l.data=s,this._dataInUrl={},s)this._dataInUrl[d]=s[d];this.setProperties?this.setProperties(l,!0):this.__setMulti(l)}else this.__resetProperties()}},__tailPathChanged:function(t){if(this.active){var e=t,a=this._matched;e&&("/"!==e.charAt(0)&&(e="/"+e),a+=e),this.set("route.path",a)}},__updatePathOnDataChange:function(){if(this.route&&this.active){var t=this.__getLink({});t!==this.__getLink(this._dataInUrl)&&this.set("route.path",t)}},__getLink:function(t){var e={tail:null};for(var a in this.data)e[a]=this.data[a];for(var a in t)e[a]=t[a];var r=this.pattern.split("/").map(function(t){return":"==t[0]&&(t=e[t.slice(1)]),t},this);return e.tail&&e.tail.path&&(r.length>0&&"/"===e.tail.path.charAt(0)?r.push(e.tail.path.slice(1)):r.push(e.tail.path)),r.join("/")},__setMulti:function(t){for(var e in t)this._propertySetter(e,t[e]);void 0!==t.data&&(this._pathEffector("data",this.data),this._notifyChange("data")),void 0!==t.active&&(this._pathEffector("active",this.active),this._notifyChange("active")),void 0!==t.tail&&(this._pathEffector("tail",this.tail),this._notifyChange("tail"))}})},323:function(t,e,a){"use strict";function r(t){if(!t||"object"!=typeof t)return t;if("[object Date]"==Object.prototype.toString.call(t))return new Date(t.getTime());if(Array.isArray(t))return t.map(r);var e={};return Object.keys(t).forEach(function(a){e[a]=r(t[a])}),e}a.d(e,"a",function(){return r})},373:function(t,e,a){"use strict";a.d(e,"a",function(){return h});var r=a(10);const i=(t,e)=>{const a=t.startNode.parentNode,i=void 0===e?t.endNode:e.startNode,s=a.insertBefore(Object(r.e)(),i);a.insertBefore(Object(r.e)(),i);const n=new r.b(t.options);return n.insertAfterNode(s),n},s=(t,e)=>(t.setValue(e),t.commit(),t),n=(t,e,a)=>{const i=t.startNode.parentNode,s=a?a.startNode:t.endNode,n=e.endNode.nextSibling;n!==s&&Object(r.j)(i,e.startNode,n,s)},o=t=>{Object(r.i)(t.startNode.parentNode,t.startNode,t.endNode.nextSibling)},c=(t,e,a)=>{const r=new Map;for(let i=e;i<=a;i++)r.set(t[i],i);return r},l=new WeakMap,u=new WeakMap,h=Object(r.f)((t,e,a)=>{let h;return void 0===a?a=e:void 0!==e&&(h=e),e=>{if(!(e instanceof r.b))throw new Error("repeat can only be used in text bindings");const d=l.get(e)||[],p=u.get(e)||[],f=[],_=[],v=[];let y,m,b=0;for(const r of t)v[b]=h?h(r,b):b,_[b]=a(r,b),b++;let g=0,P=d.length-1,w=0,q=_.length-1;for(;g<=P&&w<=q;)if(null===d[g])g++;else if(null===d[P])P--;else if(p[g]===v[w])f[w]=s(d[g],_[w]),g++,w++;else if(p[P]===v[q])f[q]=s(d[P],_[q]),P--,q--;else if(p[g]===v[q])f[q]=s(d[g],_[q]),n(e,d[g],f[q+1]),g++,q--;else if(p[P]===v[w])f[w]=s(d[P],_[w]),n(e,d[P],d[g]),P--,w++;else if(void 0===y&&(y=c(v,w,q),m=c(p,g,P)),y.has(p[g]))if(y.has(p[P])){const t=m.get(v[w]),a=void 0!==t?d[t]:null;if(null===a){const t=i(e,d[g]);s(t,_[w]),f[w]=t}else f[w]=s(a,_[w]),n(e,a,d[g]),d[t]=null;w++}else o(d[P]),P--;else o(d[g]),g++;for(;w<=q;){const t=i(e,f[q+1]);s(t,_[w]),f[w++]=t}for(;g<=P;){const t=d[g++];null!==t&&o(t)}l.set(e,f),u.set(e,v)}})}}]);
//# sourceMappingURL=chunk.80348f455b723fbaad26.js.map